@@ -98,7 +98,7 @@ class ImapClient:
 
     async def _check(self, command: str, awaitable: Awaitable[Tuple[str, Any]]) -> Any:
         res, data = await asyncio.wait_for(awaitable, self.timeout_seconds)
-        if res != "OK":
+        if res not in ("OK", b"OK"):
             raise ImportError(command, res, data)
         return data
 
@@ -118,7 +118,7 @@ class ImapClient:
                 "FETCH", self._client.fetch(f"{first_msg}:{last_msg}", "(UID RFC822)")
             )
         )
-        mail_header_regex = re.compile(r"^\d+\s+FETCH\s*\(.*UID\s+(\d+).*RFC822.*")
+        mail_header_regex = re.compile(rb"^\d+\s+FETCH\s*\(.*UID\s+(\d+).*RFC822.*")
         try:
             while True:
                 line = next(lines)
@@ -127,7 +127,7 @@ class ImapClient:
                     uid = int(match.group(1))
                     mail = next(lines)
                     terminator = next(lines)
-                    if not terminator == ")":
+                    if not terminator == b")":
                         raise ImapClientError(
                             f"Expected group termination with ')', but got '{terminator}'."
                         )
@@ -142,7 +142,7 @@ class ImapClient:
         mailboxes = [
             line
             for line in await self._check("LIST", self._client.list(".", mailbox_name))
-            if line != "LIST completed."
+            if line != b"LIST completed."
         ]
         if len(mailboxes) == 0:
             await self._check("CREATE", self._client.create(mailbox_name))
@@ -150,15 +150,21 @@ class ImapClient:
     async def uid_move(self, uid: int, destination: str):
         if self._client.has_capability("MOVE"):
             await self._check(
-                "UID MOVE", self._client.uid("move", str(uid), destination)
+                "UID MOVE",
+                self._client.uid("move", str(uid), destination),
             )
         else:
             await self._check(
-                "UID COPY", self._client.uid("copy", str(uid), destination)
+                "UID COPY",
+                self._client.uid("copy", str(uid), destination),
             )
             await self._check(
                 "UID STORE",
-                self._client.uid("store", str(uid), r"+FLAGS.SILENT (\Deleted)"),
+                self._client.uid(
+                    "store",
+                    str(uid),
+                    r"+FLAGS.SILENT (\Deleted)",
+                ),
             )
             await self._check("UID EXPUNGE", self._client.uid("expunge", str(uid)))
 
