@@ -7,6 +7,7 @@ import pytest
 
 from dmarc_metrics_exporter.app import App
 from dmarc_metrics_exporter.dmarc_metrics import DmarcMetricsCollection
+from dmarc_metrics_exporter.tests.sample_emails import create_email_with_zip_attachment
 
 from .conftest import try_until_success
 
@@ -78,3 +79,15 @@ async def test_metrics_autosave():
     finally:
         main.cancel()
         await main
+
+
+@pytest.mark.asyncio
+async def test_processes_duplicate_report_only_once():
+    mocks = AppMocks()
+    app = App(autosave_interval_seconds=0.5, **mocks.dependencies.as_flat_dict())
+    email = create_email_with_zip_attachment()
+
+    await app.process_email(email)
+    await app.process_email(email)
+
+    assert sum(m.total_count for m in mocks.metrics.values()) == 1
